@@ -118,6 +118,11 @@ def setup(ctx, yes, teacher):
     
     ctx.invoke(update)
 
+def get_course_by_name(name, courses);
+    for course in courses:
+        if course['name'] == name:
+            return course
+
 @cli.command()
 def update():
     """Update the MWC work directory"""
@@ -128,30 +133,30 @@ def update():
     G = get_backend(backend)(settings)
     mwc_home = Path(settings["work_dir"])
     mwc_home.mkdir(mode=WORK_DIR_PERMISSIONS, parents=True, exist_ok=True)
-    if settings['course'] in curr['courses']:
-        course = settings['course']
-        course_dir = mwc_home / course['slug']
-        course_dir.mkdir(mode=WORK_DIR_PERMISSIONS, exist_ok=True)
-        for unit in course['units']:
-            unit_dir = course_dir / unit['slug']
-            unit_dir.mkdir(mode=WORK_DIR_PERMISSIONS, exist_ok=True)
-            for module in unit['modules']:
-                module_dir = unit_dir / module['slug']
-                if module_dir.exists():
+    course = get_course_by_name(settings['course'], curr['courses'])
+    if course is None:
+        click.echo(error(f"Error: You are enrolled in {settings['course']}, but this course is not available. Please run mwc setup again."))
+        return 
+    course_dir = mwc_home / course['slug']
+    course_dir.mkdir(mode=WORK_DIR_PERMISSIONS, exist_ok=True)
+    for unit in course['units']:
+        unit_dir = course_dir / unit['slug']
+        unit_dir.mkdir(mode=WORK_DIR_PERMISSIONS, exist_ok=True)
+        for module in unit['modules']:
+            module_dir = unit_dir / module['slug']
+            if module_dir.exists():
+                try:
+                    G.update(module, module_dir)
+                except Exception as e:
+                    msg =  traceback.format_exception(type(e), e, e.__traceback__)
+                    print(error(''.join(msg)))
+            else:
+                if 'init_action' in module:
+                    rel_dir = module_dir.resolve().relative_to(mwc_home)
+                    click.echo(confirm(f"Initializing {module['slug']} at {rel_dir}."))
+                    click.echo(confirm("See {module['url']} for details."))
                     try:
-                        G.update(module, module_dir)
+                        G.init_module(module, module_dir)
                     except Exception as e:
                         msg =  traceback.format_exception(type(e), e, e.__traceback__)
-                        print(error(''.join(msg)))
-                else:
-                    if 'init_action' in module:
-                        rel_dir = module_dir.resolve().relative_to(mwc_home)
-                        click.echo(confirm(f"Initializing {module['slug']} at {rel_dir}."))
-                        click.echo(confirm("See {module['url']} for details."))
-                        try:
-                            G.init_module(module, module_dir)
-                        except Exception as e:
-                            msg =  traceback.format_exception(type(e), e, e.__traceback__)
-                            click.echo(error(''.join(msg)))
-    else:
-        click.echo(warning("Error: You are enrolled in {settings['course']}, but this course is not available. Please run mwc setup again."))
+                        click.echo(error(''.join(msg)))
